==> qmmp_1.1.4.orig.tar.bz2: qmmp-1.1.4/src/plugins/Input/opus/translations/opus_plugin_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>DecoderOpusFactory</name>
    <message>
        <location filename="../decoderopusfactory.cpp" line="49"/>
        <source>Opus Plugin</source>
        <translation>Plugin Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="52"/>
        <source>Ogg Opus Files</source>
        <translation>Arquivos Ogg Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="126"/>
        <source>About Opus Audio Plugin</source>
        <translation>Sobre o plugin Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="127"/>
        <source>Qmmp Opus Audio Plugin</source>
        <translation>Plugin Qmmp Opus Áudio</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="128"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>OpusMetaDataModel</name>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="55"/>
        <source>Length</source>
        <translation>Duração</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="56"/>
        <source>Sample rate</source>
        <translation>Frequência</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="56"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="57"/>
        <source>Channels</source>
        <translation>Canais</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="58"/>
        <source>Bitrate</source>
        <translation>Taxa de bits</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="58"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="59"/>
        <source>File size</source>
        <translation>Tamanho do arquivo</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="59"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Input/opus/translations/opus_plugin_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>DecoderOpusFactory</name>
    <message>
        <location filename="../decoderopusfactory.cpp" line="44"/>
        <source>Opus Plugin</source>
        <translation>Plugin Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="47"/>
        <source>Ogg Opus Files</source>
        <translation>Arquivos Ogg Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="121"/>
        <source>About Opus Audio Plugin</source>
        <translation>Sobre o plugin Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="122"/>
        <source>Qmmp Opus Audio Plugin</source>
        <translation>Plugin Qmmp Opus Audio</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="123"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpusMetaDataModel</name>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="55"/>
        <source>Length</source>
        <translation>Duração</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="56"/>
        <source>Sample rate</source>
        <translation>Frequência</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="56"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="57"/>
        <source>Channels</source>
        <translation>Canais</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="58"/>
        <source>Bitrate</source>
        <translation>Taxa de dados</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="58"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="59"/>
        <source>File size</source>
        <translation>Tamanho do arquivo</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="59"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>
